# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:		perl-Module-Signature
Version:	0.88
Release:	7.%{__distinit}%{__distvers}
Summary:	CPAN signature management utilities and modules
License:	CC0-1.0
URL:		https://metacpan.org/release/Module-Signature
Source0:	https://cpan.metacpan.org/modules/by-module/Module/Module-Signature-%{version}.tar.gz
Patch0:		Module-Signature-0.87-Fix-building-on-Perl-without-.-in-INC.patch
BuildArch:	noarch
# Module build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(base)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(lib)
# Module runtime
BuildRequires:	gnupg2
BuildRequires:	perl(constant)
BuildRequires:	perl(Digest::SHA)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::Manifest)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(Text::Diff)
BuildRequires:	perl(version)
# Test suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(IPC::Run)
BuildRequires:	perl(Pod::Usage)
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	gnupg2
Requires:	perl(Digest::SHA)
Requires:	perl(File::Temp)
Requires:	perl(IO::Socket::INET)
Requires:	perl(Text::Diff)
Requires:	perl(version)

%description
This package contains a command line tool and module for checking and creating
SIGNATURE files for Perl CPAN distributions.

%prep
%setup -q -n Module-Signature-%{version}

# Fix building without '.' in @INC (CPAN RT#120405)
%patch -P 0

%build
export GNUPGHOME=%{gnupghome}
perl Makefile.PL INSTALLDIRS=vendor --skipdeps </dev/null
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
export GNUPGHOME=%{gnupghome}
# Don't try to run signature test because it needs access over network to keyserver,
# even if we have the necessary keys already
make test TEST_SIGNATURE=0

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%doc AUTHORS Changes README *.pub
%{_bindir}/cpansign
%{perl_vendorlib}/Module/
%{_mandir}/man1/cpansign.1*
%{_mandir}/man3/Module::Signature.3*

%changelog
* Fri Oct 13 2023 Paul Howarth <paul@city-fan.org> - 0.88-7
- Drop redundant dependency of Digest::SHA1; implementation from Digest::SHA
  is used instead

* Mon Jun 26 2023 Paul Howarth <paul@city-fan.org> - 0.88-5
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Fri Mar 18 2022 Paul Howarth <paul@city-fan.org> - 0.88-2
- Don't even think about running the signature test as it requires network
  access

* Sat Dec 18 2021 Paul Howarth <paul@city-fan.org> - 0.88-1
- Update to 0.88
  - Update PAUSE keys to 2022

* Sat Jul  4 2020 Paul Howarth <paul@city-fan.org> - 0.87-1
- Update to 0.87
  - Skip 3-verify.t on Crypt::OpenPGP installations

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 0.86-1
- Update to 0.86
  - Update PAUSE and ANDK keys to 2020
  - Update documentation pertaining to SHA1
  - Fix compatibility with Crypt::OpenPGP

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 0.83-3
- Perl 5.30 rebuild

* Wed Aug 29 2018 Paul Howarth <paul@city-fan.org> - 0.83-1
- Update to 0.83
  - Update META.yml

* Tue Aug 28 2018 Paul Howarth <paul@city-fan.org> - 0.82-1
- Update to 0.82
  - Fix CRLF handling on Win32
  - Default to SHA256 on new hashes as SHA1 is deprecated
- Switch upstream from search.cpan.org to metacpan.org

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.81-7
- Use mktemp to create GNUPGHOME, simplifying build process
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon Jun 12 2017 Paul Howarth <paul@city-fan.org> - 0.81-5
- Fix building without '.' in @INC (CPAN RT#120405)

* Wed Apr  5 2017 Paul Howarth <paul@city-fan.org> - 0.81-3
- Use gnupg2 rather than gnupg (#1439089)
- Drop EL-5 support
  - Drop BuildRoot: and Group: tags
  - Drop buildroot cleaning in %%install
  - Drop explicit %%clean section

* Thu Oct 27 2016 Paul Howarth <paul@city-fan.org> - 0.81-2
- Drop runtime dependency on PAR::Dist, which creates a build dependency cycle
  with Module::Build; having Module::Signature support there is more valuable
  than having PAR::Dist support here

* Mon Sep  5 2016 Paul Howarth <paul@city-fan.org> - 0.81-1
- Update to 0.81
  - Document AUTHOR/MODULE_SIGNATURE_AUTHOR

* Sun Jun 12 2016 Paul Howarth <paul@city-fan.org> - 0.80-1
- Update to 0.80 (build process tweaks)
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Jun 23 2015 Paul Howarth <paul@city-fan.org> - 0.79-3
- Perl 5.22 rebuild

* Tue May 19 2015 Paul Howarth <paul@city-fan.org> - 0.79-1
- Update to 0.79
  - Restore "cpansign --skip" functionality

* Thu Apr  9 2015 Paul Howarth <paul@city-fan.org> - 0.78-1
- Update to 0.78
  - Fix verify() use from cpanm and CPAN.pm

* Wed Apr  8 2015 Paul Howarth <paul@city-fan.org> - 0.77-1
- Update to 0.77
  - Include the latest public keys of PAUSE, ANDK and AUDREYT
  - Clarify scripts/cpansign copyright to CC0 (#965126, CPAN RT#85466)

* Wed Apr  8 2015 Paul Howarth <paul@city-fan.org> - 0.76-1
- Update to 0.76
  - Fix signature tests by defaulting to verify(skip=>1) when
    $ENV{TEST_SIGNATURE} is true
- Reinstate signature test

* Tue Apr  7 2015 Paul Howarth <paul@city-fan.org> - 0.75-1
- Update to 0.75
  - Fix GPG signature parsing logic
  - MANIFEST.SKIP is no longer consulted unless --skip is given
  - Properly use open() modes to avoid injection attacks
  - More protection of @INC from relative paths
- Don't try to run the signature test, which needs the network

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 0.73-5
- Drop %%defattr, redundant since rpm 4.4

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 0.73-2
- Perl 5.18 rebuild

* Fri Jun  7 2013 Paul Howarth <paul@city-fan.org> - 0.73-1
- Update to 0.73
  - Constrain the user-specified digest name to /^\w+\d+$/
  - Only allow loading Digest::* from absolute paths in @INC (CVE-2013-2145)

* Wed Nov 28 2012 Paul Howarth <paul@city-fan.org> - 0.70-1
- Update to 0.70
  - Don't check gpg version if gpg does not exist

* Fri Nov  2 2012 Paul Howarth <paul@city-fan.org> - 0.69-1
- Update to 0.69
  - Support for gpg under these alternate names: gpg gpg2 gnupg gnupg2
- This release by AUDREYT -> update source URL
- Classify buildreqs by usage
- Include Andreas Koenig's GPG key in the SRPM and import it in %%prep so
  that we don't need to get it from a keyserver in %%check

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 0.68-5
- BR:/R: perl(IO::Socket::INET) and perl(Text::Diff)
- BR: perl(base), perl(constant), perl(Cwd), perl(Data::Dumper),
  perl(Exporter), perl(ExtUtils::Manifest), perl(File::Path), perl(File::Spec),
  perl(Getopt::Long), perl(lib) and perl(Pod::Usage)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Fri Jul  1 2011 Paul Howarth <paul@city-fan.org> - 0.68-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May 13 2011 Paul Howarth <paul@city-fan.org> - 0.68-1
- Update to 0.68
  - Fix breakage introduced by 0.67 (CPAN RT#68150)

* Mon Apr 18 2011 Paul Howarth <paul@city-fan.org> - 0.67-1
- Update to 0.67
  - Better handling of \r (CPAN RT#46339)
- BR: perl(IPC::Run) for test suite
- Nobody else likes macros for commands

* Tue Sep  7 2010 Paul Howarth <paul@city-fan.org> - 0.66-1
- Update to 0.66
  - Fix incompatibility with EU::Manifest 1.54 to 1.57 (CPAN RT#61124)
- Drop upstreamed patch for ExtUtils::Manifest problem

* Mon Sep  6 2010 Paul Howarth <paul@city-fan.org> - 0.65-1
- Update to 0.65 (skip MYMETA)
- Add patch to fix operation with ExtUtils::Manifest 1.54 to 1.57
- Add public key for packager-signed patched distribution

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.64-2
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 10 2010 Paul Howarth <paul@city-fan.org> - 0.64-1
- Update to 0.64
  - Avoid creating gnupg config files when invoking Makefile.PL (CPAN RT#41978)
  - Correctly detect the gnupg version on cygwin (CPAN RT#39258)
- Fix build process to avoid the need to use ~/.gnupg
- Fix dist tag to work with RHEL6 Beta

* Sun Mar 28 2010 Paul Howarth <paul@city-fan.org> - 0.63-1
- Update to 0.63 (fix diagnostic message from Makefile.PL when the user doesn't
  have gnupg or Crypt::OpenPGP)

* Wed Mar 24 2010 Paul Howarth <paul@city-fan.org> - 0.62-1
- Update to 0.62
  - Change default keyserver from pgp.mit.edu to pool.sks-keyservers.net
- This release by FLORA -> update source URL

* Thu Nov 19 2009 Paul Howarth <paul@city-fan.org> - 0.61-1
- Update to 0.61 (POD encoding changed to UTF-8)

* Tue Nov 17 2009 Paul Howarth <paul@city-fan.org> - 0.60-2
- License tag made CC0-specific rather than just "Public Domain"

* Tue Nov 17 2009 Paul Howarth <paul@city-fan.org> - 0.60-1
- Update to 0.60 (relicensed to Creative Commons CC0 1.0 Universal)
- Dist tag for Rawhide no longer needs special-casing

* Sun Sep  6 2009 Paul Howarth <paul@city-fan.org> - 0.55-5
- Define RPM macros in global scope
- Require and BuildRequire perl(Digest::SHA)

* Thu Oct 30 2008 Paul Howarth <paul@city-fan.org> - 0.55-4
- Import from Fedora
- Make PAR::Dist a hard dependency again
- Check signature in test suite

* Wed Mar  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.55-3
- Rebuild for new perl

* Tue Apr 17 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.55-2
- BuildRequire perl(ExtUtils::MakeMaker) and perl(Test::More).

* Tue Aug 22 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.55-1
- 0.55.
- Make PAR::Dist dependency a Requires(hint).

* Fri May 12 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.54-1
- 0.54, license changed to MIT.

* Wed Feb  1 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.53-1
- 0.53.

* Fri Jan 20 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.52-1
- 0.52.
- Run non-live tests during build and make live ones optional, enabled
  when building with "--with livetests".

* Mon Jan  2 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.51-1
- 0.51.

* Mon Aug 22 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.50-1
- 0.50.

* Wed Aug 10 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.45-1
- 0.45.

* Thu Apr  7 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.44-2
- Drop Epoch: 0 and 0.fdr. release prefix.

* Fri Dec 17 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.44-0.fdr.1
- Update to 0.44.

* Sun Nov 21 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.42-0.fdr.1
- Update to 0.42.

* Tue Jul  6 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.41-0.fdr.2
- Require perl(Digest::SHA1) (bug 1606).

* Mon Jul  5 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.41-0.fdr.1
- Update to 0.41.

* Fri Jul  2 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.40-0.fdr.1
- Update to 0.40.

* Fri Jun 18 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.39-0.fdr.1
- Update to 0.39.

* Mon May 31 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.38-0.fdr.4
- Really use pure_install (bug 1606).
- Fix build with older mktemp versions which require a template (bug 1606).

* Mon May 31 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.38-0.fdr.3
- Fix build in setups which do not generate debug packages (bug 1606).
- Require perl >= 1:5.6.1 for vendor install dir support.
- Use pure_install to avoid perllocal.pod workarounds.

* Sun Apr 25 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.38-0.fdr.2
- Require perl(:MODULE_COMPAT_*).

* Sat Mar 27 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.38-0.fdr.1
- First build.
